==> pan-0.9.7.tar.bz2: pan-0.9.7/pan/task-func-ptr.c <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000, 2001  Pan Development Team <pan@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

/*********************
**********************  Includes
*********************/

#include <config.h>

#include "debug.h"
#include "task-func-ptr.h"

/*********************
**********************  Defines / Enumerated types
*********************/

/*********************
**********************  Macros
*********************/

/*********************
**********************  Structures / Typedefs
*********************/

/*********************
**********************  Private Function Prototypes
*********************/

/*********************
**********************  Variables
*********************/

/***********
************  Extern
***********/

/***********
************  Public
***********/

/***********
************  Private
***********/

/*********************
**********************  BEGINNING OF SOURCE
*********************/

/************
*************  PUBLIC ROUTINES
************/

/*****
******
*****/

static void
task_func_ptr_destructor (PanObject * obj)
{
	TaskFuncPtr * task = TASK_FUNC_PTR(obj);

        debug1 (DEBUG_PAN_OBJECT, "task_func_ptr destructor: %p", obj);
	if (task->user_dtor != NULL)
		(*task->user_dtor)(task);

	task_destructor (obj);
}

static int
task_func_ptr_run (Task * task)
{
	TaskFuncPtr * tfp = TASK_FUNC_PTR(task);
	return (*tfp->run)(tfp, tfp->user_data);
}


PanObject* task_func_ptr_new (Server * server,
                              StatusItemDescribeFunc describe,
                              TaskFuncPtrRunFunc run,
                              gpointer user_data,
                              GDestroyNotify dtor)
{
	TaskFuncPtr * item;

	g_return_val_if_fail (run!=NULL, NULL);

       	item = g_new0 (TaskFuncPtr, 1);
        debug1 (DEBUG_PAN_OBJECT, "task_func_ptr_new: %p", item);
	task_constructor (TASK(item),
			  task_func_ptr_destructor,
			  describe,
			  task_func_ptr_run,
			  server, FALSE, TRUE);


	/* construct this class... */
	item->run = run;
	item->user_data = user_data;
	item->user_dtor = dtor;

	return PAN_OBJECT(item);
}

/*****
******
*****/

==> pan-0.13.2.tar.bz2: pan-0.13.2/pan/task-func-ptr.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*********************
**********************  Includes
*********************/

#include <config.h>

#include <pan/base/debug.h>
#include <pan/task-func-ptr.h>

/*********************
**********************  Defines / Enumerated types
*********************/

/*********************
**********************  Macros
*********************/

/*********************
**********************  Structures / Typedefs
*********************/

/*********************
**********************  Private Function Prototypes
*********************/

/*********************
**********************  Variables
*********************/

/***********
************  Extern
***********/

/***********
************  Public
***********/

/***********
************  Private
***********/

/*********************
**********************  BEGINNING OF SOURCE
*********************/

/************
*************  PUBLIC ROUTINES
************/

/*****
******
*****/

static void
task_func_ptr_destructor (PanObject * obj)
{
	TaskFuncPtr * task = TASK_FUNC_PTR(obj);

        debug1 (DEBUG_PAN_OBJECT, "task_func_ptr destructor: %p", obj);
	if (task->user_dtor != NULL)
		(*task->user_dtor)(task->user_data);

	task_destructor (obj);
}

static int
task_func_ptr_run (Task * task)
{
	TaskFuncPtr * tfp = TASK_FUNC_PTR(task);
	return (*tfp->run)(tfp, tfp->user_data);
}


PanObject* task_func_ptr_new (Server * server,
                              StatusItemDescribeFunc describe,
                              TaskFuncPtrRunFunc run,
                              GDestroyNotify dtor,
                              gpointer user_data,
                              gboolean high_priority)
{
	TaskFuncPtr * item;

	g_return_val_if_fail (run!=NULL, NULL);

       	item = g_new0 (TaskFuncPtr, 1);
        debug1 (DEBUG_PAN_OBJECT, "task_func_ptr_new: %p", item);
	task_constructor (TASK(item),
			  task_func_ptr_destructor,
			  describe,
			  task_func_ptr_run,
			  server, high_priority, TRUE);


	/* construct this class... */
	item->run = run;
	item->user_data = user_data;
	item->user_dtor = dtor;

	return PAN_OBJECT(item);
}

/*****
******
*****/
